from .matchers.parsable.test_parsable_json import assert_parsable_json
from .matchers.parsable.test_parsable_csv import assert_parsable_csv
from .matchers.parsable.test_parsable_xml import assert_parsable_xml
from .matchers.parsable.test_parsable_yaml import assert_parsable_yaml

from .matchers.uses.test_uses_html import assert_is_html
from .matchers.uses.test_uses_latex import assert_is_latex
from .matchers.uses.test_uses_markdown import assert_is_markdown

from .matchers.style.test_conciseness import assert_concise_answer, assert_conciseness

from .matchers.test_fulfills import assert_fulfills


import pytest
from unitprompt.llm import LLM

async def assert_fulfills(received: str, prompt):
    
    # Check if prompt is a list, if not, convert it to a list
    if not isinstance(prompt, list):
        prompt = [prompt]
    
    llm = LLM()
    
    unfulfilled_conditions = []
    for condition in prompt:
        complete_prompt = "<Goal>Check whether the input satisfies the condition</Goal>"
        complete_prompt += "<Condition>{condition}</Condition>"
        complete_prompt += "<Input>{received}</Input>"
        
        llm.model.max_tokens = 1
        complete_prompt += "<Response>If condition satisfied: 1, if condition is not satisfied: 0</Response>"
            
        result = await llm.invoke(complete_prompt, { "received": received, "condition": condition })
        
        if result != "1":
            unfulfilled_conditions.append(condition)

    if len(unfulfilled_conditions) > 0:
        raise pytest.fail(f"Expected {received} to satisfy the following conditions: {unfulfilled_conditions}, but it did not.")